#!/bin/bash

apt-get -y install whiptail software-properties-common python-software-properties

cmd=(whiptail --separate-output --checklist "Install and configure the following packages::" 22 76 16)
options=(1 "nginx" off    # any option can be set to default to "on"
		 2 "tomcat & lucee" off
		 3 "mysql" off
		 4 "mongodb" off)
choices=$("${cmd[@]}" "${options[@]}" 2>&1 >/dev/tty)
clear

#Firewall
ufw allow ssh
ufw enable

for choice in $choices
do
	case $choice in
		1)
			echo "Adding nginx repo"
			#Needed for nginx/tengine
			add-apt-repository -y ppa:titusx/tengine-edge
			;;
		2)
			echo "Adding java repo"
			#Needed for Oracle Java 8:
			add-apt-repository -y ppa:webupd8team/java
			;;
		4)
			echo "Adding mongodb repo"
			#Needed for MongoDB
			apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv 7F0CEB10
			echo "deb http://repo.mongodb.org/apt/ubuntu "$(lsb_release -sc)"/mongodb-org/3.0 multiverse" | tee /etc/apt/sources.list.d/mongodb-org-3.0.list
			;;
	esac
done

apt-get update

apt-get -y install unzip vim-nox htop libtcnative-1

for choice in $choices
do
	case $choice in
		1)
			echo "Installing nginx"
			ufw allow http
			ufw allow https
			apt-get -y install nginx nginx-common
			# nginx en en disable site scripts
			git clone https://github.com/jzuijlek/nginx_ensite.git
			cp nginx_ensite/nginx_*site /usr/local/bin
			cp -r root/etc/nginx /etc
			mkdir /etc/nginx/ssl
			openssl dhparam -out /etc/nginx/ssl/dhparams.pem 2048
			;;
		2)
			echo "Installing tomcat & lucee"
			cp -r root/etc/tomcat7 /etc
			cp -r root/etc/default /etc
			echo oracle-java8-installer shared/accepted-oracle-license-v1-1 select true | debconf-set-selections
			apt-get -y install oracle-java8-installer oracle-java8-set-default tomcat7 rng-tools
			mkdir /var/lib/tomcat7/lucee
			cd /var/lib/tomcat7/lucee
			curl -L -0 http://bitbucket.org/lucee/lucee/downloads/lucee-4.5.1.022-jars.zip > lucee.zip
			unzip lucee.zip
			rm lucee.zip
			curl -o mod_cfml-valve_v1.1.04.jar https://raw.githubusercontent.com/utdream/mod_cfml/master/java/mod_cfml-valve_v1.1.04.jar
			chown -R tomcat7:tomcat7 /var/lib/tomcat7/lucee
			mkdir /etc/lucee
			chown tomcat7:tomcat7 /etc/lucee
			cd -
			;;
		3)
			echo "Installing mysql"
			apt-get -y install mysql-server-5.6 mysql-client-5.6
			;;
		4)
			echo "Installing mongodb"
			cp root/etc/mongodb.conf /etc
			apt-get -y install mongodb-org
			;;
	esac
done

for choice in $choices
do
	case $choice in
		2)
			#Herstart rng-tools voor kernel entropy
			service rng-tools restart

			#Herstart tomcat
			service tomcat7 restart

			;;
	esac
done

# upgrade remaining packages
apt-get -y dist-upgrade

# auto remove obsolute packages
apt-get -y autoremove

# restart ssh
service ssh restart